#
# spec file for package python-django-reversion
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-django-reversion
Version:        1.8.6
Release:        6.1
Url:            http://github.com/etianen/django-reversion
Summary:        An app that provides comprehensive version control facilities for Django
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/d/django-reversion/django-reversion-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
Requires:       python-django
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
django-reversion is an extension to the Django web framework that provides
comprehensive version control facilities.

* Roll back to any point in a model's history - an unlimited undo facility!
* Recover deleted models - never lose data again!
* Admin integration for maximum usability.
* Group related changes into revisions that can be rolled back in a single transaction.
* Automatically save a new version whenever your model changes using Django's flexible signalling framework.
* Automate your revision management with easy-to-use middleware.


%prep
%setup -q -n django-reversion-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGELOG.rst LICENSE README.rst
%{python_sitelib}/*

%changelog
* Wed Apr 22 2015 mcihar@suse.cz
- Update to version 1.8.6:
  - Support for MySQL utf8mb4 (@alexhayes).
  - Fixing some Django deprecation warnings (Drew Hubl, @khakulov, @adonm).
  - Versions passed through by reversion.post_revision_commit now contain a primary key (@joelarson).
  - Added support for proxy models (@AgDude, @bourivouh).
  - Allowing registration of models with django-reversion using custom signals (@ErwinJunge).
  - Fixing some Django deprecation warnings (@skipp, @narrowfail).
  - Fixing including legacy south migrations in PyPi package (@GeyseR).
  - Provisional Django 1.7 support (@etianen).
  - Multi-db and multi-manager support to management commands (@marekmalek).
  - Added index on reversion.date_created (@rkojedzinszky).
  - Minor bugfixes and documentation improvements (@coagulant).
  - reversion.register() can now be used as a class decorator (@aquavitae).
  - Danish translation (@Vandborg).
  - Improvements to Travis CI integration (@thedrow).
  - Simplified Chinese translation (@QuantumGhost).
  - Minor bugfixes and documentation improvements (@marekmalek, @dhoffman34, @mauricioabreu, @mark0978).
  - Slovak translation (@jbub).
  - Deleting a user no longer deletes the associated revisions (@daaray).
  - Improving handling of inline models in admin integration (@blueyed).
  - Improving error messages for proxy model registration (@blueyed).
  - Improvements to using migrations with custom user model (@aivins).
  - Removing sys.exit() in deleterevisions management command, allowing it to be used internally by Django projects (@tongwang).
  - Fixing some backwards-compatible admin deprecation warnings (Thomas Schreiber).
  - Fixing tests if RevisionMiddleware is used as a decorator in the parent project (@jmoldow).
  - Derived models, such as those generated by deferred querysets, now work.
* Thu Jan 23 2014 mcihar@suse.cz
- Update to version 1.8.0:
  + Django 1.6 compatibility (@niwibe & @meshy).
  + Removing type flag from Version model.
  + Using bulk_create to speed up revision creation.
  + Including docs in source distribution (@pquentin & @fladi).
  + Spanish translation (@alexander-ae).
  + Fixing edge-case bugs in revision middleware (@pricem & @oppianmatt).
- Improve package description
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 1.7.1
  + Bugfixes when using a custom User model.
  + Minor bugfixes.
- Use download url as source url
- Add documentation from tarball
* Wed Dec 12 2012 alexandre@exatati.com.br
- Update to 1.6.5:
  - Support for Django 1.4.3.
* Mon Oct 29 2012 alexandre@exatati.com.br
- Update to 1.6.4:
  - Support for Django 1.4.2.
* Thu Sep  6 2012 alexandre@exatati.com.br
- Update to 1.6.3:
  - Fixing issue with reverting models with unique constraints in
    the admin.
  - Enforcing permissions in admin views.
* Tue Jul 31 2012 alexandre@exatati.com.br
- Update to 1.6.2:
  - Batch saving option in createinitialrevisions.
  - Suppressing warning for Django 1.4.1.
- Aditional changes from 1.6.1:
  - Swedish translation.
  - Fixing formating for PyPi readme and license.
  - Minor features and bugfixes.
* Tue Mar 27 2012 alexandre@exatati.com.br
- Update to 1.6.0:
  - Django 1.4 compatibility.
* Wed Oct 26 2011 alexandre@exatati.com.br
- Update to 1.5.1:
  - Sorry, no changelog atm.
* Mon Sep  5 2011 alexandre@exatati.com.br
- Update to 1.5:
  - Added in simplified low level API methods, and deprecated old
    low level API methods.
  - Added in support for multiple revision managers running in the
    same project.
  - Added in significant speedups for models with integer primary
    keys.
  - Added in cleanup improvements to patch generation helpers.
  - Minor bug fixes.
* Wed Apr 27 2011 alexandre@exatati.com.br
- Update to 1.4:
  - Sorry, no changelog.
* Tue Apr 19 2011 alexandre@exatati.com.br
- Regenerate spec file with py2pack.
* Mon Mar  7 2011 alexandre@exatati.com.br
- Update to 1.3.3.
* Fri Oct 22 2010 alexandre@exatati.com.br
- Update to 1.3.2.
* Mon May 31 2010 alexandre@exatati.com.br
- Update to 1.3.1.
* Mon May 31 2010 alexandre@exatati.com.br
- Update to 1.3;
- Spec file cleaned with spec-cleaner.
* Wed Mar  3 2010 alexandre@exatati.com.br
- Update to 1.2.1.
* Tue Oct 13 2009 alexandre@exatati.com.br
- Initial package (1.2) for openSUSE.
